==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/SvgImport/ts/SvgImport_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SvgImport</name>
    <message>
        <location filename="../SvgImport.js" line="+30"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Import SVG</source>
        <translation>SVGインポート</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SVG Files</source>
        <translation>SVGファイル</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>All Files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <location filename="../SvgImportInit.js" line="+2"/>
        <source>SVG &amp;Import...</source>
        <translation>&amp;I SVGインポート...</translation>
    </message>
    <message>
        <location filename="../SvgImport.js" line="-34"/>
        <location filename="../SvgImportDialog.ui" line="+14"/>
        <source>SVG Import</source>
        <translation>SVGインポート</translation>
    </message>
    <message>
        <location filename="../SvgImportDialog.ui" line="+8"/>
        <source>Resolution:</source>
        <translation>解像度:</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Pixels / Inch</source>
        <translation>ピクセル·パー·インチ</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Splines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically convert splines to lines / arcs if appropriate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/SvgImport/ts/SvgImport_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SvgImport</name>
    <message>
        <location filename="../SvgImport.js" line="+30"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Import SVG</source>
        <translation>SVGインポート</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SVG Files</source>
        <translation>SVGファイル</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>All Files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <location filename="../SvgImportInit.js" line="+2"/>
        <source>SVG &amp;Import...</source>
        <translation>&amp;I SVGインポート...</translation>
    </message>
    <message>
        <location filename="../SvgImport.js" line="-34"/>
        <location filename="../SvgImportDialog.ui" line="+14"/>
        <source>SVG Import</source>
        <translation>SVGインポート</translation>
    </message>
    <message>
        <location filename="../SvgImportDialog.ui" line="+8"/>
        <source>Resolution:</source>
        <translation>解像度:</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Pixels / Inch</source>
        <translation>ピクセル·パー·インチ</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Splines</source>
        <translation>スプライン曲線</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically convert splines to lines / arcs if appropriate</source>
        <translation>もし適当であればスプラインを線分・弧に自動コンバート</translation>
    </message>
</context>
</TS>
